==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangingEventArgsDetailDescription } from "./WebColumnVisibilityChangingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebColumnVisibilityChangingEventArgsDetail", () => new WebColumnVisibilityChangingEventArgsDetailDescription());
            a.z("WebColumnVisibilityChangingEventArgsDetail", WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangingEventArgsDetailDescription } from "./WebColumnVisibilityChangingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebColumnVisibilityChangingEventArgsDetail", () => new WebColumnVisibilityChangingEventArgsDetailDescription());
            a.ab("WebColumnVisibilityChangingEventArgsDetail", WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata;
})();
